@@ -1,5 +1,7 @@
 package LL;
 
+use strict;
+use warnings;
 use base qw(Date::Holidays::Abstract);
 
 sub holidays {}
